@@ -7,7 +7,9 @@ Collection of cdk8s constructs for deploying [Metaflow](https://metaflow.org) on
 
 ```shell
 cdk8s import k8s@1.22.0 -l typescript -o src/imports
-cdk8s import github:minio/operator@4.4.22 -l typescript -o src/imports
+helm repo add bitnami https://charts.bitnami.com/bitnami
+helm repo add argo https://charts.bitnami.com/bitnami
+helm repo add autoscaler https://kubernetes.github.io/autoscaler
 ```
 '''
 import abc
@@ -25,7 +27,7 @@ from typeguard import check_type
 from ._jsii import *
 
 import cdk8s
-import cdk8s_plus_22
+import cdk8s_plus_21
 import constructs
 
 
@@ -393,6 +395,82 @@ class DatabaseVolumePermissionsOptions:
         )
 
 
+@jsii.data_type(
+    jsii_type="cdk8s-metaflow.HelmPostgresAddonProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "chart_version": "chartVersion",
+        "namespace_name": "namespaceName",
+        "chart_values": "chartValues",
+    },
+)
+class HelmPostgresAddonProps:
+    def __init__(
+        self,
+        *,
+        chart_version: builtins.str,
+        namespace_name: builtins.str,
+        chart_values: typing.Optional[typing.Union["MetadataDatabaseOptions", typing.Dict[str, typing.Any]]] = None,
+    ) -> None:
+        '''
+        :param chart_version: 
+        :param namespace_name: 
+        :param chart_values: 
+
+        :stability: experimental
+        '''
+        if isinstance(chart_values, dict):
+            chart_values = MetadataDatabaseOptions(**chart_values)
+        if __debug__:
+            type_hints = typing.get_type_hints(HelmPostgresAddonProps.__init__)
+            check_type(argname="argument chart_version", value=chart_version, expected_type=type_hints["chart_version"])
+            check_type(argname="argument namespace_name", value=namespace_name, expected_type=type_hints["namespace_name"])
+            check_type(argname="argument chart_values", value=chart_values, expected_type=type_hints["chart_values"])
+        self._values: typing.Dict[str, typing.Any] = {
+            "chart_version": chart_version,
+            "namespace_name": namespace_name,
+        }
+        if chart_values is not None:
+            self._values["chart_values"] = chart_values
+
+    @builtins.property
+    def chart_version(self) -> builtins.str:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("chart_version")
+        assert result is not None, "Required property 'chart_version' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def namespace_name(self) -> builtins.str:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("namespace_name")
+        assert result is not None, "Required property 'namespace_name' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def chart_values(self) -> typing.Optional["MetadataDatabaseOptions"]:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("chart_values")
+        return typing.cast(typing.Optional["MetadataDatabaseOptions"], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "HelmPostgresAddonProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.interface(jsii_type="cdk8s-metaflow.IAddon")
 class IAddon(typing_extensions.Protocol):
     '''
@@ -408,7 +486,7 @@ class IAddon(typing_extensions.Protocol):
         ...
 
     @jsii.member(jsii_name="install")
-    def install(self, scope: constructs.Construct) -> cdk8s.Helm:
+    def install(self, scope: constructs.Construct) -> constructs.Construct:
         '''
         :param scope: -
 
@@ -433,7 +511,7 @@ class _IAddonProxy:
         return typing.cast(builtins.str, jsii.get(self, "name"))
 
     @jsii.member(jsii_name="install")
-    def install(self, scope: constructs.Construct) -> cdk8s.Helm:
+    def install(self, scope: constructs.Construct) -> constructs.Construct:
         '''
         :param scope: -
 
@@ -442,12 +520,125 @@ class _IAddonProxy:
         if __debug__:
             type_hints = typing.get_type_hints(IAddon.install)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-        return typing.cast(cdk8s.Helm, jsii.invoke(self, "install", [scope]))
+        return typing.cast(constructs.Construct, jsii.invoke(self, "install", [scope]))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
 typing.cast(typing.Any, IAddon).__jsii_proxy_class__ = lambda : _IAddonProxy
 
 
+@jsii.implements(IAddon)
+class LocalPostgresAddon(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="cdk8s-metaflow.LocalPostgresAddon",
+):
+    '''
+    :stability: experimental
+    '''
+
+    def __init__(
+        self,
+        *,
+        endpoint_ip: builtins.str,
+        namespace_name: typing.Optional[builtins.str] = None,
+    ) -> None:
+        '''
+        :param endpoint_ip: 
+        :param namespace_name: 
+
+        :stability: experimental
+        '''
+        props = LocalPostgresAddonProps(
+            endpoint_ip=endpoint_ip, namespace_name=namespace_name
+        )
+
+        jsii.create(self.__class__, self, [props])
+
+    @jsii.member(jsii_name="install")
+    def install(self, scope: constructs.Construct) -> constructs.Construct:
+        '''
+        :param scope: -
+
+        :stability: experimental
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(LocalPostgresAddon.install)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+        return typing.cast(constructs.Construct, jsii.invoke(self, "install", [scope]))
+
+    @jsii.python.classproperty
+    @jsii.member(jsii_name="NAME")
+    def NAME(cls) -> builtins.str:
+        '''
+        :stability: experimental
+        '''
+        return typing.cast(builtins.str, jsii.sget(cls, "NAME"))
+
+    @builtins.property
+    @jsii.member(jsii_name="name")
+    def name(self) -> builtins.str:
+        '''
+        :stability: experimental
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "name"))
+
+
+@jsii.data_type(
+    jsii_type="cdk8s-metaflow.LocalPostgresAddonProps",
+    jsii_struct_bases=[],
+    name_mapping={"endpoint_ip": "endpointIp", "namespace_name": "namespaceName"},
+)
+class LocalPostgresAddonProps:
+    def __init__(
+        self,
+        *,
+        endpoint_ip: builtins.str,
+        namespace_name: typing.Optional[builtins.str] = None,
+    ) -> None:
+        '''
+        :param endpoint_ip: 
+        :param namespace_name: 
+
+        :stability: experimental
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(LocalPostgresAddonProps.__init__)
+            check_type(argname="argument endpoint_ip", value=endpoint_ip, expected_type=type_hints["endpoint_ip"])
+            check_type(argname="argument namespace_name", value=namespace_name, expected_type=type_hints["namespace_name"])
+        self._values: typing.Dict[str, typing.Any] = {
+            "endpoint_ip": endpoint_ip,
+        }
+        if namespace_name is not None:
+            self._values["namespace_name"] = namespace_name
+
+    @builtins.property
+    def endpoint_ip(self) -> builtins.str:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("endpoint_ip")
+        assert result is not None, "Required property 'endpoint_ip' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def namespace_name(self) -> typing.Optional[builtins.str]:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("namespace_name")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "LocalPostgresAddonProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.data_type(
     jsii_type="cdk8s-metaflow.MetadataDatabaseOptions",
     jsii_struct_bases=[],
@@ -581,11 +772,11 @@ class MetadataDatabaseOptions:
         "namespace": "namespace",
         "image": "image",
         "image_tag": "imageTag",
-        "service_account": "serviceAccount",
-        "service_type": "serviceType",
+        "service_port": "servicePort",
         "env_vars": "envVars",
         "init_image": "initImage",
         "init_image_tag": "initImageTag",
+        "service_account": "serviceAccount",
     },
 )
 class MetaflowChartProps(cdk8s.ChartProps):
@@ -596,41 +787,42 @@ class MetaflowChartProps(cdk8s.ChartProps):
         namespace: typing.Optional[builtins.str] = None,
         image: builtins.str,
         image_tag: builtins.str,
-        service_account: cdk8s_plus_22.ServiceAccount,
-        service_type: cdk8s_plus_22.ServiceType,
+        service_port: typing.Union[cdk8s_plus_21.ServicePort, typing.Dict[str, typing.Any]],
         env_vars: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         init_image: typing.Optional[builtins.str] = None,
         init_image_tag: typing.Optional[builtins.str] = None,
+        service_account: typing.Optional[cdk8s_plus_21.IServiceAccount] = None,
     ) -> None:
         '''
         :param labels: Labels to apply to all resources in this chart. Default: - no common labels
         :param namespace: The default namespace for all objects defined in this chart (directly or indirectly). This namespace will only apply to objects that don't have a ``namespace`` explicitly defined for them. Default: - no namespace is synthesized (usually this implies "default")
         :param image: 
         :param image_tag: 
-        :param service_account: 
-        :param service_type: 
+        :param service_port: 
         :param env_vars: 
         :param init_image: 
         :param init_image_tag: 
+        :param service_account: 
 
         :stability: experimental
         '''
+        if isinstance(service_port, dict):
+            service_port = ServicePort(**service_port)
         if __debug__:
             type_hints = typing.get_type_hints(MetaflowChartProps.__init__)
             check_type(argname="argument labels", value=labels, expected_type=type_hints["labels"])
             check_type(argname="argument namespace", value=namespace, expected_type=type_hints["namespace"])
             check_type(argname="argument image", value=image, expected_type=type_hints["image"])
             check_type(argname="argument image_tag", value=image_tag, expected_type=type_hints["image_tag"])
-            check_type(argname="argument service_account", value=service_account, expected_type=type_hints["service_account"])
-            check_type(argname="argument service_type", value=service_type, expected_type=type_hints["service_type"])
+            check_type(argname="argument service_port", value=service_port, expected_type=type_hints["service_port"])
             check_type(argname="argument env_vars", value=env_vars, expected_type=type_hints["env_vars"])
             check_type(argname="argument init_image", value=init_image, expected_type=type_hints["init_image"])
             check_type(argname="argument init_image_tag", value=init_image_tag, expected_type=type_hints["init_image_tag"])
+            check_type(argname="argument service_account", value=service_account, expected_type=type_hints["service_account"])
         self._values: typing.Dict[str, typing.Any] = {
             "image": image,
             "image_tag": image_tag,
-            "service_account": service_account,
-            "service_type": service_type,
+            "service_port": service_port,
         }
         if labels is not None:
             self._values["labels"] = labels
@@ -642,6 +834,8 @@ class MetaflowChartProps(cdk8s.ChartProps):
             self._values["init_image"] = init_image
         if init_image_tag is not None:
             self._values["init_image_tag"] = init_image_tag
+        if service_account is not None:
+            self._values["service_account"] = service_account
 
     @builtins.property
     def labels(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
@@ -683,22 +877,13 @@ class MetaflowChartProps(cdk8s.ChartProps):
         return typing.cast(builtins.str, result)
 
     @builtins.property
-    def service_account(self) -> cdk8s_plus_22.ServiceAccount:
+    def service_port(self) -> cdk8s_plus_21.ServicePort:
         '''
         :stability: experimental
         '''
-        result = self._values.get("service_account")
-        assert result is not None, "Required property 'service_account' is missing"
-        return typing.cast(cdk8s_plus_22.ServiceAccount, result)
-
-    @builtins.property
-    def service_type(self) -> cdk8s_plus_22.ServiceType:
-        '''
-        :stability: experimental
-        '''
-        result = self._values.get("service_type")
-        assert result is not None, "Required property 'service_type' is missing"
-        return typing.cast(cdk8s_plus_22.ServiceType, result)
+        result = self._values.get("service_port")
+        assert result is not None, "Required property 'service_port' is missing"
+        return typing.cast(cdk8s_plus_21.ServicePort, result)
 
     @builtins.property
     def env_vars(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
@@ -724,6 +909,14 @@ class MetaflowChartProps(cdk8s.ChartProps):
         result = self._values.get("init_image_tag")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def service_account(self) -> typing.Optional[cdk8s_plus_21.IServiceAccount]:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("service_account")
+        return typing.cast(typing.Optional[cdk8s_plus_21.IServiceAccount], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -736,10 +929,10 @@ class MetaflowChartProps(cdk8s.ChartProps):
         )
 
 
-class MetaflowServiceChart(
+class MetaflowService(
     cdk8s.Chart,
     metaclass=jsii.JSIIMeta,
-    jsii_type="cdk8s-metaflow.MetaflowServiceChart",
+    jsii_type="cdk8s-metaflow.MetaflowService",
 ):
     '''
     :stability: experimental
@@ -752,11 +945,11 @@ class MetaflowServiceChart(
         *,
         image: builtins.str,
         image_tag: builtins.str,
-        service_account: cdk8s_plus_22.ServiceAccount,
-        service_type: cdk8s_plus_22.ServiceType,
+        service_port: typing.Union[cdk8s_plus_21.ServicePort, typing.Dict[str, typing.Any]],
         env_vars: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         init_image: typing.Optional[builtins.str] = None,
         init_image_tag: typing.Optional[builtins.str] = None,
+        service_account: typing.Optional[cdk8s_plus_21.IServiceAccount] = None,
         labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         namespace: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -765,28 +958,28 @@ class MetaflowServiceChart(
         :param name: -
         :param image: 
         :param image_tag: 
-        :param service_account: 
-        :param service_type: 
+        :param service_port: 
         :param env_vars: 
         :param init_image: 
         :param init_image_tag: 
+        :param service_account: 
         :param labels: Labels to apply to all resources in this chart. Default: - no common labels
         :param namespace: The default namespace for all objects defined in this chart (directly or indirectly). This namespace will only apply to objects that don't have a ``namespace`` explicitly defined for them. Default: - no namespace is synthesized (usually this implies "default")
 
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(MetaflowServiceChart.__init__)
+            type_hints = typing.get_type_hints(MetaflowService.__init__)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
         props = MetaflowChartProps(
             image=image,
             image_tag=image_tag,
-            service_account=service_account,
-            service_type=service_type,
+            service_port=service_port,
             env_vars=env_vars,
             init_image=init_image,
             init_image_tag=init_image_tag,
+            service_account=service_account,
             labels=labels,
             namespace=namespace,
         )
@@ -794,172 +987,19 @@ class MetaflowServiceChart(
         jsii.create(self.__class__, self, [scope, name, props])
 
     @builtins.property
-    @jsii.member(jsii_name="deployment")
-    def deployment(self) -> cdk8s_plus_22.Deployment:
+    @jsii.member(jsii_name="serviceAccount")
+    def service_account(self) -> typing.Optional[cdk8s_plus_21.IServiceAccount]:
         '''
         :stability: experimental
         '''
-        return typing.cast(cdk8s_plus_22.Deployment, jsii.get(self, "deployment"))
-
-    @builtins.property
-    @jsii.member(jsii_name="service")
-    def service(self) -> cdk8s_plus_22.Service:
-        '''
-        :stability: experimental
-        '''
-        return typing.cast(cdk8s_plus_22.Service, jsii.get(self, "service"))
-
-
-class MetaflowUIChart(
-    cdk8s.Chart,
-    metaclass=jsii.JSIIMeta,
-    jsii_type="cdk8s-metaflow.MetaflowUIChart",
-):
-    '''
-    :stability: experimental
-    '''
-
-    def __init__(
-        self,
-        scope: constructs.Construct,
-        name: builtins.str,
-        *,
-        image: builtins.str,
-        image_tag: builtins.str,
-        service_account: cdk8s_plus_22.ServiceAccount,
-        service_type: cdk8s_plus_22.ServiceType,
-        env_vars: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-        init_image: typing.Optional[builtins.str] = None,
-        init_image_tag: typing.Optional[builtins.str] = None,
-        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-        namespace: typing.Optional[builtins.str] = None,
-    ) -> None:
-        '''
-        :param scope: -
-        :param name: -
-        :param image: 
-        :param image_tag: 
-        :param service_account: 
-        :param service_type: 
-        :param env_vars: 
-        :param init_image: 
-        :param init_image_tag: 
-        :param labels: Labels to apply to all resources in this chart. Default: - no common labels
-        :param namespace: The default namespace for all objects defined in this chart (directly or indirectly). This namespace will only apply to objects that don't have a ``namespace`` explicitly defined for them. Default: - no namespace is synthesized (usually this implies "default")
-
-        :stability: experimental
-        '''
-        if __debug__:
-            type_hints = typing.get_type_hints(MetaflowUIChart.__init__)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
-        props = MetaflowChartProps(
-            image=image,
-            image_tag=image_tag,
-            service_account=service_account,
-            service_type=service_type,
-            env_vars=env_vars,
-            init_image=init_image,
-            init_image_tag=init_image_tag,
-            labels=labels,
-            namespace=namespace,
-        )
-
-        jsii.create(self.__class__, self, [scope, name, props])
-
-    @builtins.property
-    @jsii.member(jsii_name="deployment")
-    def deployment(self) -> cdk8s_plus_22.Deployment:
-        '''
-        :stability: experimental
-        '''
-        return typing.cast(cdk8s_plus_22.Deployment, jsii.get(self, "deployment"))
-
-    @builtins.property
-    @jsii.member(jsii_name="service")
-    def service(self) -> cdk8s_plus_22.Service:
-        '''
-        :stability: experimental
-        '''
-        return typing.cast(cdk8s_plus_22.Service, jsii.get(self, "service"))
-
-
-class MetaflowUIStaticChart(
-    cdk8s.Chart,
-    metaclass=jsii.JSIIMeta,
-    jsii_type="cdk8s-metaflow.MetaflowUIStaticChart",
-):
-    '''
-    :stability: experimental
-    '''
-
-    def __init__(
-        self,
-        scope: constructs.Construct,
-        name: builtins.str,
-        *,
-        image: builtins.str,
-        image_tag: builtins.str,
-        service_account: cdk8s_plus_22.ServiceAccount,
-        service_type: cdk8s_plus_22.ServiceType,
-        env_vars: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-        init_image: typing.Optional[builtins.str] = None,
-        init_image_tag: typing.Optional[builtins.str] = None,
-        labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-        namespace: typing.Optional[builtins.str] = None,
-    ) -> None:
-        '''
-        :param scope: -
-        :param name: -
-        :param image: 
-        :param image_tag: 
-        :param service_account: 
-        :param service_type: 
-        :param env_vars: 
-        :param init_image: 
-        :param init_image_tag: 
-        :param labels: Labels to apply to all resources in this chart. Default: - no common labels
-        :param namespace: The default namespace for all objects defined in this chart (directly or indirectly). This namespace will only apply to objects that don't have a ``namespace`` explicitly defined for them. Default: - no namespace is synthesized (usually this implies "default")
-
-        :stability: experimental
-        '''
-        if __debug__:
-            type_hints = typing.get_type_hints(MetaflowUIStaticChart.__init__)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
-        props = MetaflowChartProps(
-            image=image,
-            image_tag=image_tag,
-            service_account=service_account,
-            service_type=service_type,
-            env_vars=env_vars,
-            init_image=init_image,
-            init_image_tag=init_image_tag,
-            labels=labels,
-            namespace=namespace,
-        )
-
-        jsii.create(self.__class__, self, [scope, name, props])
-
-    @builtins.property
-    @jsii.member(jsii_name="deployment")
-    def deployment(self) -> cdk8s_plus_22.Deployment:
-        '''
-        :stability: experimental
-        '''
-        return typing.cast(cdk8s_plus_22.Deployment, jsii.get(self, "deployment"))
-
-    @builtins.property
-    @jsii.member(jsii_name="service")
-    def service(self) -> cdk8s_plus_22.Service:
-        '''
-        :stability: experimental
-        '''
-        return typing.cast(cdk8s_plus_22.Service, jsii.get(self, "service"))
+        return typing.cast(typing.Optional[cdk8s_plus_21.IServiceAccount], jsii.get(self, "serviceAccount"))
 
 
 @jsii.implements(IAddon)
-class PostgresAddon(metaclass=jsii.JSIIMeta, jsii_type="cdk8s-metaflow.PostgresAddon"):
+class HelmPostgresAddon(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="cdk8s-metaflow.HelmPostgresAddon",
+):
     '''
     :stability: experimental
     '''
@@ -978,7 +1018,7 @@ class PostgresAddon(metaclass=jsii.JSIIMeta, jsii_type="cdk8s-metaflow.PostgresA
 
         :stability: experimental
         '''
-        props = PostgresAddonProps(
+        props = HelmPostgresAddonProps(
             chart_version=chart_version,
             namespace_name=namespace_name,
             chart_values=chart_values,
@@ -987,16 +1027,16 @@ class PostgresAddon(metaclass=jsii.JSIIMeta, jsii_type="cdk8s-metaflow.PostgresA
         jsii.create(self.__class__, self, [props])
 
     @jsii.member(jsii_name="install")
-    def install(self, scope: constructs.Construct) -> cdk8s.Helm:
+    def install(self, scope: constructs.Construct) -> constructs.Construct:
         '''
         :param scope: -
 
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PostgresAddon.install)
+            type_hints = typing.get_type_hints(HelmPostgresAddon.install)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-        return typing.cast(cdk8s.Helm, jsii.invoke(self, "install", [scope]))
+        return typing.cast(constructs.Construct, jsii.invoke(self, "install", [scope]))
 
     @jsii.python.classproperty
     @jsii.member(jsii_name="NAME")
@@ -1015,82 +1055,6 @@ class PostgresAddon(metaclass=jsii.JSIIMeta, jsii_type="cdk8s-metaflow.PostgresA
         return typing.cast(builtins.str, jsii.get(self, "name"))
 
 
-@jsii.data_type(
-    jsii_type="cdk8s-metaflow.PostgresAddonProps",
-    jsii_struct_bases=[],
-    name_mapping={
-        "chart_version": "chartVersion",
-        "namespace_name": "namespaceName",
-        "chart_values": "chartValues",
-    },
-)
-class PostgresAddonProps:
-    def __init__(
-        self,
-        *,
-        chart_version: builtins.str,
-        namespace_name: builtins.str,
-        chart_values: typing.Optional[typing.Union[MetadataDatabaseOptions, typing.Dict[str, typing.Any]]] = None,
-    ) -> None:
-        '''
-        :param chart_version: 
-        :param namespace_name: 
-        :param chart_values: 
-
-        :stability: experimental
-        '''
-        if isinstance(chart_values, dict):
-            chart_values = MetadataDatabaseOptions(**chart_values)
-        if __debug__:
-            type_hints = typing.get_type_hints(PostgresAddonProps.__init__)
-            check_type(argname="argument chart_version", value=chart_version, expected_type=type_hints["chart_version"])
-            check_type(argname="argument namespace_name", value=namespace_name, expected_type=type_hints["namespace_name"])
-            check_type(argname="argument chart_values", value=chart_values, expected_type=type_hints["chart_values"])
-        self._values: typing.Dict[str, typing.Any] = {
-            "chart_version": chart_version,
-            "namespace_name": namespace_name,
-        }
-        if chart_values is not None:
-            self._values["chart_values"] = chart_values
-
-    @builtins.property
-    def chart_version(self) -> builtins.str:
-        '''
-        :stability: experimental
-        '''
-        result = self._values.get("chart_version")
-        assert result is not None, "Required property 'chart_version' is missing"
-        return typing.cast(builtins.str, result)
-
-    @builtins.property
-    def namespace_name(self) -> builtins.str:
-        '''
-        :stability: experimental
-        '''
-        result = self._values.get("namespace_name")
-        assert result is not None, "Required property 'namespace_name' is missing"
-        return typing.cast(builtins.str, result)
-
-    @builtins.property
-    def chart_values(self) -> typing.Optional[MetadataDatabaseOptions]:
-        '''
-        :stability: experimental
-        '''
-        result = self._values.get("chart_values")
-        return typing.cast(typing.Optional[MetadataDatabaseOptions], result)
-
-    def __eq__(self, rhs: typing.Any) -> builtins.bool:
-        return isinstance(rhs, self.__class__) and rhs._values == self._values
-
-    def __ne__(self, rhs: typing.Any) -> builtins.bool:
-        return not (rhs == self)
-
-    def __repr__(self) -> str:
-        return "PostgresAddonProps(%s)" % ", ".join(
-            k + "=" + repr(v) for k, v in self._values.items()
-        )
-
-
 __all__ = [
     "DatabaseAuthOptions",
     "DatabaseMetricsOptions",
@@ -1098,14 +1062,14 @@ __all__ = [
     "DatabaseResourceRequestOptions",
     "DatabaseResourcesOptions",
     "DatabaseVolumePermissionsOptions",
+    "HelmPostgresAddon",
+    "HelmPostgresAddonProps",
     "IAddon",
+    "LocalPostgresAddon",
+    "LocalPostgresAddonProps",
     "MetadataDatabaseOptions",
     "MetaflowChartProps",
-    "MetaflowServiceChart",
-    "MetaflowUIChart",
-    "MetaflowUIStaticChart",
-    "PostgresAddon",
-    "PostgresAddonProps",
+    "MetaflowService",
 ]
 
 publication.publish()
